@@ -2,6 +2,7 @@ import re
 from typing import Optional
 
 from strictdoc.backend.sdoc.models.document import Document
+from strictdoc.backend.sdoc.models.reference import FileReference
 from strictdoc.backend.sdoc.models.requirement import Requirement
 from strictdoc.backend.sdoc.models.section import Section
 from strictdoc.core.finders.source_files_finder import SourceFile
@@ -76,7 +77,7 @@ class LinkRenderer:
         else:
             self.req_link_cache[link_cache_key] = {}
         document_link = node.document.meta.get_html_link(
-            DocumentType.document(), source_file.level + 2
+            DocumentType.document(), source_file.level + 1
         )
         requirement_link = f"{document_link}#{local_link}"
         self.req_link_cache[link_cache_key][node] = requirement_link
@@ -84,27 +85,30 @@ class LinkRenderer:
 
     @staticmethod
     def render_source_file_link(
-        requirement: Requirement, source_file_link: str
+        requirement: Requirement, file_reference: FileReference
     ):
-        document: Document = requirement.ng_document_reference.get_document()
+        assert isinstance(file_reference, FileReference)
+
+        document_or_none: Optional[
+            Document
+        ] = requirement.ng_document_reference.get_document()
+        assert document_or_none is not None
+        document: Document = document_or_none
         path_prefix = document.meta.get_root_path_prefix()
         source_file_link = (
             f"{path_prefix}"
-            f"/_source_files"
-            f"/{document.meta.file_tree_mount_folder}"
-            f"/{source_file_link}.html"
+            "/"
+            f"_source_files"
+            "/"
+            f"{file_reference.path_forward_slashes}.html"
         )
         return source_file_link
 
     @staticmethod
-    def render_source_file_link_from_root(
-        requirement: Requirement, source_file_link: str
-    ):
-        document: Document = requirement.ng_document_reference.get_document()
+    def render_source_file_link_from_root(file_reference: FileReference):
+        assert isinstance(file_reference, FileReference)
         source_file_link = (
-            f"_source_files"
-            f"/{document.meta.file_tree_mount_folder}"
-            f"/{source_file_link}.html"
+            f"_source_files/{file_reference.path_forward_slashes}.html"
         )
         return source_file_link
 
@@ -112,52 +116,31 @@ class LinkRenderer:
     def render_source_file_link_from_root_2(source_file: SourceFile):
         assert isinstance(source_file, SourceFile)
         source_file_link = (
-            f"_source_files"
-            f"/{source_file.doctree_root_mount_path}"
-            f"/{source_file.in_doctree_source_file_rel_path}.html"
-        )
-        return source_file_link
-
-    @staticmethod
-    def render_source_file_link_from_source_file(
-        source_file: SourceFile, requirement: Requirement, source_file_link: str
-    ):
-        assert isinstance(source_file, SourceFile)
-        document: Document = requirement.ng_document_reference.get_document()
-
-        def get_root_path_prefix(level):
-            assert level > 0
-            return ("../" * level)[:-1]
-
-        path_prefix = get_root_path_prefix(source_file.level + 1)
-
-        source_file_link = (
-            f"{path_prefix}"
-            f"/{document.meta.file_tree_mount_folder}"
-            f"/{source_file_link}.html#"
+            "_source_files"
+            "/"
+            f"{source_file.in_doctree_source_file_rel_path}.html"
         )
         return source_file_link
 
     @staticmethod
     def render_requirement_in_source_file_link(
         requirement: Requirement,
-        source_link: str,
+        source_link: FileReference,
         context_source_file: SourceFile,
     ):
-        assert isinstance(source_link, str)
-        assert len(source_link) > 0
+        assert isinstance(source_link, FileReference)
+        assert len(source_link.path) > 0
 
         def get_root_path_prefix(level):
             if level == 0:
                 return ".."
             return ("../" * level)[:-1]
 
-        path_prefix = get_root_path_prefix(context_source_file.level + 2)
+        path_prefix = get_root_path_prefix(context_source_file.level + 1)
         source_file_link = (
             f"{path_prefix}"
             f"/_source_files"
-            f"/{context_source_file.doctree_root_mount_path}"
-            f"/{source_link}.html#{requirement.uid}"
+            f"/{source_link.path_forward_slashes}.html#{requirement.uid}"
         )
         return source_file_link
 
@@ -169,6 +152,7 @@ class LinkRenderer:
         source_range,
     ):
         assert isinstance(source_link, str)
+        assert isinstance(context_source_file, SourceFile)
         assert len(source_link) > 0
 
         def get_root_path_prefix(level):
@@ -176,11 +160,10 @@ class LinkRenderer:
                 return ".."
             return ("../" * level)[:-1]
 
-        path_prefix = get_root_path_prefix(context_source_file.level + 2)
+        path_prefix = get_root_path_prefix(context_source_file.level + 1)
         source_file_link = (
             f"{path_prefix}"
             f"/_source_files"
-            f"/{context_source_file.doctree_root_mount_path}"
             f"/{source_link}.html"
             f"#{req_uid}"
             f"#{source_range.ng_range_line_begin}"
@@ -191,12 +174,17 @@ class LinkRenderer:
     def render_requirement_in_source_file_range_link(
         self,
         requirement: Requirement,
-        source_link: str,
+        source_link: FileReference,
         context_source_file: SourceFile,
         source_range,
     ):
+        assert isinstance(source_link, FileReference)
+        assert isinstance(context_source_file, SourceFile)
         return self.render_requirement_in_source_file_range_link_using_id(
-            requirement.uid, source_link, context_source_file, source_range
+            requirement.uid,
+            source_link.path_forward_slashes,
+            context_source_file,
+            source_range,
         )
 
     @staticmethod
