@@ -3,7 +3,6 @@ from enum import Enum
 from strictdoc.backend.sdoc.models.inline_link import InlineLink
 from strictdoc.backend.sdoc.models.requirement import Requirement
 from strictdoc.backend.sdoc.models.section import FreeText, Section
-from strictdoc.backend.sdoc.models.special_field import SpecialField
 from strictdoc.core.document_iterator import DocumentCachingIterator
 from strictdoc.core.traceability_index import TraceabilityIndex
 
@@ -23,7 +22,7 @@ class RSTWriter:
         output = ""
 
         if not single_document:
-            output += self._print_rst_header(document.name, 0)
+            output += self._print_rst_header(document.title, 0)
 
         for free_text in document.free_texts:
             output += self._print_free_text(free_text)
@@ -64,7 +63,6 @@ class RSTWriter:
     def _print_requirement_fields(self, section_content: Requirement):
         output = ""
 
-        meta_table_started = False
         if section_content.uid:
             output += f".. _{section_content.uid}:"
             output += "\n\n"
@@ -72,7 +70,6 @@ class RSTWriter:
                 section_content.title, section_content.ng_level
             )
 
-            meta_table_started = True
             output += ".. list-table::\n"
             output += "    :align: left\n"
             output += "    :header-rows: 0\n\n"
@@ -84,19 +81,6 @@ class RSTWriter:
             output += self._print_rst_header(
                 section_content.title, section_content.ng_level
             )
-        if section_content.special_fields and len(
-            section_content.special_fields
-        ):
-            if not meta_table_started:
-                output += ".. list-table::\n"
-                output += "    :align: left\n"
-                output += "    :header-rows: 0\n\n"
-
-            special_field: SpecialField
-            for special_field in section_content.special_fields:
-                output += f"    * - **{special_field.field_name}:**\n"
-                output += f"      - {special_field.field_value}\n"
-                output += "\n"
 
         if section_content.statement:
             output += section_content.statement
@@ -107,11 +91,6 @@ class RSTWriter:
         else:
             pass  # raise RuntimeError('Statement is missing')
 
-        if section_content.body:
-            output += "\n"
-            output += section_content.body
-            output += "\n\n"
-
         for comment in section_content.comments:
             output += "**"
             output += "Comment:"
